# piligraphs
[![pypi](https://img.shields.io/pypi/v/piligraphs)](https://pypi.org/project/piligraphs)
[![python](https://img.shields.io/badge/python-3.11-blue)](https://www.python.org/downloads)
[![python](https://img.shields.io/badge/support-yellow)](https://www.buymeacoffee.com/eeemoon)

[Pillow](https://github.com/python-pillow/Pillow) extension for drawing graphs and charts.

![](examples/images/allgraphs.png)

### You can find more examples [here](examples/)
